@@ -26,6 +26,7 @@
 #include "thumbnail_viewer.h"
 
 static ThunarVfsMimeDatabase *mime_dbase = NULL;
+static GtkIconTheme *icon_theme = NULL;
 
 static void
 cb_rstto_zoom_fit(GtkToolItem *item, RsttoPictureViewer *viewer);
@@ -62,6 +63,8 @@ static void
 cb_rstto_clear_recent(GtkWidget *widget, GtkRecentManager *manager);
 static gboolean
 rstto_clear_recent(GtkRecentManager *manager);
+static void
+cb_rstto_close_current(GtkWidget *item, RsttoNavigator *navigator);
 
 static void
 cb_rstto_help_about(GtkToolItem *item, GtkWindow *);
@@ -91,6 +94,8 @@ static gboolean
 cb_rstto_key_press_event(GtkWidget *widget, GdkEventKey *event, RsttoNavigator *navigator);
 static void
 cb_rstto_nav_file_changed(RsttoNavigator *navigator, gint nr, RsttoNavigatorEntry *entry, GtkWindow *window);
+static void
+cb_rstto_spawn_app(GtkWidget *widget, ThunarVfsMimeApplication *app);
 
 static gboolean window_fullscreen = FALSE;
 static GtkWidget *menu_bar;
@@ -102,6 +107,9 @@ static GtkWidget *menu_item_pause;
 static GtkWidget *menu_item_htv;
 static GtkWidget *menu_item_vtv;
 static GtkWidget *menu_item_ntv;
+static GtkWidget *menu_edit;
+static GtkWidget *menu_apps;
+static GList     *menu_apps_list;
 
 static GtkWidget *main_hbox;
 static GtkWidget *main_vbox1;
@@ -110,6 +118,13 @@ static GtkRecentManager *recent_manager;
 static XfceRc *xfce_rc;
 static const gchar *thumbnail_viewer_orientation;
 static gint window_save_geometry_timer_id = 0;
+static GtkWidget *menu_item_close;
+static GtkWidget *menu_item_first;
+static GtkWidget *menu_item_last;
+static GtkWidget *menu_item_forward;
+static GtkWidget *menu_item_back;
+static GtkToolItem *tool_item_forward;
+static GtkToolItem *tool_item_previous;
 
 int main(int argc, char **argv)
 {
@@ -129,6 +144,7 @@ int main(int argc, char **argv)
     thunar_vfs_init();
 
     mime_dbase = thunar_vfs_mime_database_get_default();
+    icon_theme = gtk_icon_theme_get_default();
 
     gtk_window_set_default_icon_name("ristretto");
     recent_manager = gtk_recent_manager_get_default();
@@ -159,6 +175,238 @@ int main(int argc, char **argv)
     g_signal_connect(G_OBJECT(navigator), "iter-changed", G_CALLBACK(cb_rstto_nav_file_changed), window);
 
 
+    GtkWidget *s_window = gtk_scrolled_window_new(NULL,NULL);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(s_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    GtkWidget *main_vbox = gtk_vbox_new(0, FALSE);
+    main_hbox = gtk_hbox_new(0, FALSE);
+    main_vbox1 = gtk_vbox_new(0, FALSE);
+    menu_bar = gtk_menu_bar_new();
+    app_tool_bar = gtk_toolbar_new();
+    status_bar = gtk_statusbar_new();
+
+    GtkWidget *menu_item_file = gtk_menu_item_new_with_mnemonic(_("_File"));
+    GtkWidget *menu_item_open = gtk_image_menu_item_new_from_stock(GTK_STOCK_OPEN, accel_group);
+    GtkWidget *menu_item_open_dir = gtk_menu_item_new_with_mnemonic(_("O_pen Folder"));
+    GtkWidget *menu_item_recently = gtk_menu_item_new_with_mnemonic(_("_Recently used"));
+    GtkWidget *menu_item_separator = gtk_separator_menu_item_new();
+    menu_item_close = gtk_image_menu_item_new_from_stock(GTK_STOCK_CLOSE, accel_group);
+    GtkWidget *menu_item_quit = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, accel_group);
+
+    GtkWidget *menu_file = gtk_menu_new();
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_file), menu_file);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_open);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_open_dir);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_recently);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_separator);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_close);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_quit);
+    gtk_widget_set_sensitive(menu_item_close, FALSE);
+    
+    GtkWidget *recent_chooser_menu = gtk_recent_chooser_menu_new_for_manager(GTK_RECENT_MANAGER(recent_manager));
+    GtkRecentFilter *filter = gtk_recent_filter_new();
+    gtk_recent_filter_add_application(filter, "ristretto");
+    gtk_recent_chooser_add_filter(GTK_RECENT_CHOOSER(recent_chooser_menu), filter);
+    
+    GtkWidget *menu_item_clear_recent = gtk_image_menu_item_new_from_stock(GTK_STOCK_CLEAR, accel_group);
+    menu_item_separator = gtk_separator_menu_item_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(recent_chooser_menu), menu_item_separator);
+    gtk_menu_shell_append(GTK_MENU_SHELL(recent_chooser_menu), menu_item_clear_recent);
+    
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_recently), recent_chooser_menu);
+
+    GtkWidget *menu_item_edit = gtk_menu_item_new_with_mnemonic(_("_Edit"));
+    GtkWidget *menu_item_rotate_left = gtk_menu_item_new_with_mnemonic(_("Rotate _Left"));
+    GtkWidget *menu_item_rotate_right = gtk_menu_item_new_with_mnemonic(_("Rotate _Right"));
+    GtkWidget *menu_item_flip_v = gtk_menu_item_new_with_mnemonic(_("Flip _Vertically"));
+    GtkWidget *menu_item_flip_h = gtk_menu_item_new_with_mnemonic(_("Flip _Horizontally"));
+    GtkWidget *menu_item_apps = gtk_menu_item_new_with_mnemonic(_("_Open with..."));
+
+    menu_edit = gtk_menu_new();
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_edit), menu_edit);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_apps);
+
+    menu_apps = gtk_menu_new();
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_apps), menu_apps);
+    GtkWidget *bottom_menu_item = gtk_menu_item_new_with_mnemonic(_("No applications available"));
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_apps), bottom_menu_item);
+    gtk_widget_set_sensitive(bottom_menu_item, FALSE);
+    /* 
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_rotate_left);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_rotate_right);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_flip_v);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_flip_h);
+    */
+
+    GtkWidget *menu_item_view = gtk_menu_item_new_with_mnemonic(_("_View"));
+    GtkWidget *menu_item_toggle_toolbar = gtk_check_menu_item_new_with_mnemonic(_("Show Toolbar"));
+    GtkWidget *menu_item_tv = gtk_menu_item_new_with_mnemonic(_("Thumbnail Viewer"));
+    GtkWidget *menu_item_view_fs = gtk_image_menu_item_new_from_stock(GTK_STOCK_FULLSCREEN, NULL);
+    gtk_widget_add_accelerator(menu_item_view_fs, "activate", accel_group, GDK_F11, 0,GTK_ACCEL_VISIBLE);
+
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item_toggle_toolbar), show_toolbar);
+
+    GtkWidget *menu_view = gtk_menu_new();
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_view), menu_view);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_view), menu_item_toggle_toolbar);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_view), menu_item_tv);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_view), menu_item_view_fs);
+
+    GtkWidget *menu_tv = gtk_menu_new();
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_tv), menu_tv);
+    menu_item_htv = gtk_radio_menu_item_new_with_mnemonic(NULL, _("Show Horizontally"));
+    menu_item_vtv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Show Vertically"));
+    menu_item_ntv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Hide"));
+
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_htv);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_vtv);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_ntv);
+
+    GtkWidget *menu_item_go = gtk_menu_item_new_with_mnemonic(_("_Go"));
+
+    menu_item_first = gtk_image_menu_item_new_from_stock(GTK_STOCK_GOTO_FIRST, NULL);
+    menu_item_last = gtk_image_menu_item_new_from_stock(GTK_STOCK_GOTO_LAST, NULL);
+    menu_item_forward = gtk_image_menu_item_new_from_stock(GTK_STOCK_GO_FORWARD, NULL);
+    menu_item_back = gtk_image_menu_item_new_from_stock(GTK_STOCK_GO_BACK, NULL);
+    gtk_widget_add_accelerator(menu_item_first, "activate", accel_group, GDK_Home, 0,GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(menu_item_last, "activate", accel_group, GDK_End, 0,GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(menu_item_forward, "activate", accel_group, GDK_Page_Down, 0,GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(menu_item_back, "activate", accel_group, GDK_Page_Up, 0,GTK_ACCEL_VISIBLE);
+    gtk_widget_set_sensitive(menu_item_first, FALSE);
+    gtk_widget_set_sensitive(menu_item_last, FALSE);
+    gtk_widget_set_sensitive(menu_item_back, FALSE);
+    gtk_widget_set_sensitive(menu_item_forward, FALSE);
+
+    menu_item_play = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_PLAY, accel_group);
+    menu_item_pause = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_PAUSE, accel_group);
+    gtk_widget_add_accelerator(menu_item_play, "activate", accel_group, GDK_F5, 0,GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(menu_item_pause, "activate", accel_group, GDK_F5, 0,GTK_ACCEL_VISIBLE);
+
+    menu_item_separator = gtk_separator_menu_item_new();
+
+    GtkWidget *menu_go = gtk_menu_new();
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_go), menu_go);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_first);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_last);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_forward);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_back);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_separator);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_play);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_pause);
+
+    GtkWidget *menu_item_help = gtk_menu_item_new_with_mnemonic(_("_Help"));
+    GtkWidget *menu_item_help_about = gtk_image_menu_item_new_from_stock(GTK_STOCK_ABOUT, accel_group);
+
+    GtkWidget *menu_help = gtk_menu_new();
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_help), menu_help);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_help), menu_item_help_about);
+
+
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_file);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_edit);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_view);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_go);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_help);
+
+    GtkToolItem *zoom_fit= gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_FIT);
+    GtkToolItem *zoom_100= gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_100);
+    GtkToolItem *zoom_out= gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_OUT);
+    GtkToolItem *zoom_in = gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_IN);
+    tool_item_forward = gtk_tool_button_new_from_stock(GTK_STOCK_GO_FORWARD);
+    tool_item_previous = gtk_tool_button_new_from_stock(GTK_STOCK_GO_BACK);
+    GtkToolItem *open = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
+    GtkToolItem *spacer = gtk_tool_item_new();
+    GtkToolItem *separator = gtk_separator_tool_item_new();
+
+    gtk_tool_item_set_is_important(tool_item_previous, TRUE);
+    gtk_tool_item_set_is_important(tool_item_forward, TRUE);
+    gtk_widget_set_sensitive(GTK_WIDGET(tool_item_forward), FALSE);
+    gtk_widget_set_sensitive(GTK_WIDGET(tool_item_previous), FALSE);
+
+    gtk_tool_item_set_expand(spacer, TRUE);
+    gtk_tool_item_set_homogeneous(spacer, FALSE);
+
+    gtk_window_set_default_size(GTK_WINDOW(window), window_width, window_height);
+
+    gtk_container_add(GTK_CONTAINER(s_window), viewer);
+    gtk_box_pack_start(GTK_BOX(main_hbox), main_vbox1, TRUE, TRUE, 0);
+
+    gtk_box_pack_start(GTK_BOX(main_vbox1), s_window, TRUE, TRUE, 0);
+    if(!strcmp(thumbnail_viewer_orientation, "horizontal"))
+    {
+        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item_htv), TRUE);
+        gtk_box_pack_start(GTK_BOX(main_vbox1), thumbnail_viewer, FALSE, TRUE, 0);
+        rstto_thumbnail_viewer_set_orientation(RSTTO_THUMBNAIL_VIEWER(thumbnail_viewer), GTK_ORIENTATION_HORIZONTAL);
+    }
+    else
+    {
+        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item_vtv), TRUE);
+        gtk_box_pack_start(GTK_BOX(main_hbox), thumbnail_viewer, FALSE, TRUE, 0);
+        rstto_thumbnail_viewer_set_orientation(RSTTO_THUMBNAIL_VIEWER(thumbnail_viewer), GTK_ORIENTATION_VERTICAL);
+    }
+
+
+    gtk_box_pack_start(GTK_BOX(main_vbox), menu_bar, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(main_vbox), app_tool_bar, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(main_vbox), main_hbox, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(main_vbox), status_bar, FALSE, TRUE, 0);
+
+
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_fit, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_100, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_out, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_in, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), spacer, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), tool_item_forward, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), tool_item_previous, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), separator, 0);
+    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), open, 0);
+
+    g_signal_connect(G_OBJECT(zoom_fit), "clicked", G_CALLBACK(cb_rstto_zoom_fit), viewer);
+    g_signal_connect(G_OBJECT(zoom_100), "clicked", G_CALLBACK(cb_rstto_zoom_100), viewer);
+    g_signal_connect(G_OBJECT(zoom_in), "clicked", G_CALLBACK(cb_rstto_zoom_in), viewer);
+    g_signal_connect(G_OBJECT(zoom_out), "clicked", G_CALLBACK(cb_rstto_zoom_out), viewer);
+    g_signal_connect(G_OBJECT(tool_item_forward), "clicked", G_CALLBACK(cb_rstto_forward), navigator);
+    g_signal_connect(G_OBJECT(tool_item_previous), "clicked", G_CALLBACK(cb_rstto_previous), navigator);
+    if(toolbar_open_dir == TRUE)
+        g_signal_connect(G_OBJECT(open), "clicked", G_CALLBACK(cb_rstto_open_dir), navigator);
+    else
+        g_signal_connect(G_OBJECT(open), "clicked", G_CALLBACK(cb_rstto_open), navigator);
+
+    g_signal_connect(G_OBJECT(menu_item_clear_recent), "activate", G_CALLBACK(cb_rstto_clear_recent), recent_manager);
+
+    g_signal_connect(G_OBJECT(menu_item_quit), "activate", G_CALLBACK(gtk_main_quit), NULL);
+    g_signal_connect(G_OBJECT(menu_item_open), "activate", G_CALLBACK(cb_rstto_open), navigator);
+    g_signal_connect(G_OBJECT(menu_item_open_dir), "activate", G_CALLBACK(cb_rstto_open_dir), navigator);
+    g_signal_connect(G_OBJECT(menu_item_help_about), "activate", G_CALLBACK(cb_rstto_help_about), window);
+    g_signal_connect(G_OBJECT(menu_item_close), "activate", G_CALLBACK(cb_rstto_close_current), navigator);
+
+    g_signal_connect(G_OBJECT(recent_chooser_menu), "item-activated", G_CALLBACK(cb_rstto_open_recent), navigator);
+
+    g_signal_connect(G_OBJECT(menu_item_forward), "activate", G_CALLBACK(cb_rstto_forward), navigator);
+    g_signal_connect(G_OBJECT(menu_item_back), "activate", G_CALLBACK(cb_rstto_previous), navigator);
+    g_signal_connect(G_OBJECT(menu_item_first), "activate", G_CALLBACK(cb_rstto_first), navigator);
+    g_signal_connect(G_OBJECT(menu_item_last), "activate", G_CALLBACK(cb_rstto_last), navigator);
+
+    g_signal_connect(G_OBJECT(menu_item_rotate_left), "activate", G_CALLBACK(cb_rstto_rotate_ccw), navigator);
+    g_signal_connect(G_OBJECT(menu_item_rotate_right), "activate", G_CALLBACK(cb_rstto_rotate_cw), navigator);
+    g_signal_connect(G_OBJECT(menu_item_flip_v), "activate", G_CALLBACK(cb_rstto_flip_v), navigator);
+    g_signal_connect(G_OBJECT(menu_item_flip_h), "activate", G_CALLBACK(cb_rstto_flip_h), navigator);
+
+    g_signal_connect(G_OBJECT(menu_item_toggle_toolbar), "activate", G_CALLBACK(cb_rstto_toggle_toolbar), thumbnail_viewer);
+
+    g_signal_connect(G_OBJECT(menu_item_vtv), "activate", G_CALLBACK(cb_rstto_show_tv_v), thumbnail_viewer);
+    g_signal_connect(G_OBJECT(menu_item_htv), "activate", G_CALLBACK(cb_rstto_show_tv_h), thumbnail_viewer);
+    g_signal_connect(G_OBJECT(menu_item_ntv), "activate", G_CALLBACK(cb_rstto_hide_tv), thumbnail_viewer);
+
+    g_signal_connect(G_OBJECT(menu_item_play), "activate", G_CALLBACK(cb_rstto_toggle_play), navigator);
+    g_signal_connect(G_OBJECT(menu_item_pause), "activate", G_CALLBACK(cb_rstto_toggle_play), navigator);
+    g_signal_connect(G_OBJECT(menu_item_view_fs), "activate", G_CALLBACK(cb_rstto_toggle_fullscreen), window);
+
+    g_signal_connect(G_OBJECT(window), "window-state-event", G_CALLBACK(cb_rstto_fullscreen), viewer);
+    g_signal_connect(G_OBJECT(window), "configure-event", G_CALLBACK(cb_rstto_main_window_configure_event), NULL);
+
+    gtk_container_add(GTK_CONTAINER(window), main_vbox);
+
     for (n = 1; n < argc; ++n)
     {
         path = thunar_vfs_path_new(argv[n], NULL);
@@ -203,224 +451,6 @@ int main(int argc, char **argv)
         thunar_vfs_path_unref(path);
     }
 
-
-    GtkWidget *s_window = gtk_scrolled_window_new(NULL,NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(s_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    GtkWidget *main_vbox = gtk_vbox_new(0, FALSE);
-    main_hbox = gtk_hbox_new(0, FALSE);
-    main_vbox1 = gtk_vbox_new(0, FALSE);
-    menu_bar = gtk_menu_bar_new();
-    app_tool_bar = gtk_toolbar_new();
-    status_bar = gtk_statusbar_new();
-
-    GtkWidget *menu_item_file = gtk_menu_item_new_with_mnemonic(_("_File"));
-    GtkWidget *menu_item_open = gtk_image_menu_item_new_from_stock(GTK_STOCK_OPEN, accel_group);
-    GtkWidget *menu_item_open_dir = gtk_menu_item_new_with_mnemonic(_("O_pen Folder"));
-    GtkWidget *menu_item_recently = gtk_menu_item_new_with_mnemonic(_("_Recently used"));
-    GtkWidget *menu_item_separator = gtk_separator_menu_item_new();
-    /* GtkWidget *menu_item_close = gtk_image_menu_item_new_from_stock(GTK_STOCK_CLOSE, accel_group); */
-    GtkWidget *menu_item_quit = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, accel_group);
-
-    GtkWidget *menu_file = gtk_menu_new();
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_file), menu_file);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_open);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_open_dir);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_recently);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_separator);
-    /* gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_close);*/
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_quit);
-    
-    GtkWidget *recent_chooser_menu = gtk_recent_chooser_menu_new_for_manager(GTK_RECENT_MANAGER(recent_manager));
-    GtkRecentFilter *filter = gtk_recent_filter_new();
-    gtk_recent_filter_add_application(filter, "ristretto");
-    gtk_recent_chooser_add_filter(GTK_RECENT_CHOOSER(recent_chooser_menu), filter);
-    
-    GtkWidget *menu_item_clear_recent = gtk_image_menu_item_new_with_mnemonic(_("_Clear"));
-    GtkWidget *img_clear_recent = gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU);
-    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item_clear_recent), img_clear_recent);
-    menu_item_separator = gtk_separator_menu_item_new();
-    gtk_menu_shell_append(GTK_MENU_SHELL(recent_chooser_menu), menu_item_separator);
-    gtk_menu_shell_append(GTK_MENU_SHELL(recent_chooser_menu), menu_item_clear_recent);
-    
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_recently), recent_chooser_menu);
-
-    GtkWidget *menu_item_edit = gtk_menu_item_new_with_mnemonic(_("_Edit"));
-    GtkWidget *menu_item_rotate_left = gtk_menu_item_new_with_mnemonic(_("Rotate _Left"));
-    GtkWidget *menu_item_rotate_right = gtk_menu_item_new_with_mnemonic(_("Rotate _Right"));
-    GtkWidget *menu_item_flip_v = gtk_menu_item_new_with_mnemonic(_("Flip _Vertically"));
-    GtkWidget *menu_item_flip_h = gtk_menu_item_new_with_mnemonic(_("Flip _Horizontally"));
-
-    GtkWidget *menu_edit = gtk_menu_new();
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_edit), menu_edit);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_rotate_left);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_rotate_right);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_flip_v);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_edit), menu_item_flip_h);
-
-    GtkWidget *menu_item_view = gtk_menu_item_new_with_mnemonic(_("_View"));
-    GtkWidget *menu_item_toggle_toolbar = gtk_check_menu_item_new_with_mnemonic(_("Show Toolbar"));
-    GtkWidget *menu_item_tv = gtk_menu_item_new_with_mnemonic(_("Thumbnail Viewer"));
-    GtkWidget *menu_item_view_fs = gtk_image_menu_item_new_from_stock(GTK_STOCK_FULLSCREEN, NULL);
-    gtk_widget_add_accelerator(menu_item_view_fs, "activate", accel_group, GDK_F11, 0,GTK_ACCEL_VISIBLE);
-
-    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item_toggle_toolbar), show_toolbar);
-
-    GtkWidget *menu_view = gtk_menu_new();
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_view), menu_view);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_view), menu_item_toggle_toolbar);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_view), menu_item_tv);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_view), menu_item_view_fs);
-
-    GtkWidget *menu_tv = gtk_menu_new();
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_tv), menu_tv);
-    menu_item_htv = gtk_radio_menu_item_new_with_mnemonic(NULL, _("Show Horizontally"));
-    menu_item_vtv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Show Vertically"));
-    menu_item_ntv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Hide"));
-
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_htv);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_vtv);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_ntv);
-
-    GtkWidget *menu_item_go = gtk_menu_item_new_with_mnemonic(_("_Go"));
-
-    GtkWidget *menu_item_first = gtk_image_menu_item_new_from_stock(GTK_STOCK_GOTO_FIRST, NULL);
-    GtkWidget *menu_item_last = gtk_image_menu_item_new_from_stock(GTK_STOCK_GOTO_LAST, NULL);
-    GtkWidget *menu_item_forward = gtk_image_menu_item_new_from_stock(GTK_STOCK_GO_FORWARD, NULL);
-    GtkWidget *menu_item_back = gtk_image_menu_item_new_from_stock(GTK_STOCK_GO_BACK, NULL);
-    gtk_widget_add_accelerator(menu_item_first, "activate", accel_group, GDK_Home, 0,GTK_ACCEL_VISIBLE);
-    gtk_widget_add_accelerator(menu_item_last, "activate", accel_group, GDK_End, 0,GTK_ACCEL_VISIBLE);
-    gtk_widget_add_accelerator(menu_item_forward, "activate", accel_group, GDK_Page_Down, 0,GTK_ACCEL_VISIBLE);
-    gtk_widget_add_accelerator(menu_item_back, "activate", accel_group, GDK_Page_Up, 0,GTK_ACCEL_VISIBLE);
-
-    menu_item_play = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_PLAY, accel_group);
-    menu_item_pause = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_PAUSE, accel_group);
-    gtk_widget_add_accelerator(menu_item_play, "activate", accel_group, GDK_F5, 0,GTK_ACCEL_VISIBLE);
-    gtk_widget_add_accelerator(menu_item_pause, "activate", accel_group, GDK_F5, 0,GTK_ACCEL_VISIBLE);
-
-    menu_item_separator = gtk_separator_menu_item_new();
-
-    GtkWidget *menu_go = gtk_menu_new();
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_go), menu_go);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_first);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_last);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_forward);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_back);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_separator);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_play);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_go), menu_item_pause);
-
-    GtkWidget *menu_item_help = gtk_menu_item_new_with_mnemonic(_("_Help"));
-    GtkWidget *menu_item_help_about = gtk_image_menu_item_new_from_stock(GTK_STOCK_ABOUT, accel_group);
-
-    GtkWidget *menu_help = gtk_menu_new();
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_help), menu_help);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_help), menu_item_help_about);
-
-
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_file);
-    /*gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_edit);*/
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_view);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_go);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item_help);
-
-    GtkToolItem *zoom_fit= gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_FIT);
-    GtkToolItem *zoom_100= gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_100);
-    GtkToolItem *zoom_out= gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_OUT);
-    GtkToolItem *zoom_in = gtk_tool_button_new_from_stock(GTK_STOCK_ZOOM_IN);
-    GtkToolItem *forward = gtk_tool_button_new_from_stock(GTK_STOCK_GO_FORWARD);
-    GtkToolItem *previous = gtk_tool_button_new_from_stock(GTK_STOCK_GO_BACK);
-    GtkToolItem *open = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
-    GtkToolItem *spacer = gtk_tool_item_new();
-    GtkToolItem *separator = gtk_separator_tool_item_new();
-
-    gtk_tool_item_set_is_important(previous, TRUE);
-    gtk_tool_item_set_is_important(forward, TRUE);
-
-    gtk_tool_item_set_expand(spacer, TRUE);
-    gtk_tool_item_set_homogeneous(spacer, FALSE);
-
-    gtk_window_set_default_size(GTK_WINDOW(window), window_width, window_height);
-
-    gtk_container_add(GTK_CONTAINER(s_window), viewer);
-    gtk_box_pack_start(GTK_BOX(main_hbox), main_vbox1, TRUE, TRUE, 0);
-
-    gtk_box_pack_start(GTK_BOX(main_vbox1), s_window, TRUE, TRUE, 0);
-    if(!strcmp(thumbnail_viewer_orientation, "horizontal"))
-    {
-        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item_htv), TRUE);
-        gtk_box_pack_start(GTK_BOX(main_vbox1), thumbnail_viewer, FALSE, TRUE, 0);
-        rstto_thumbnail_viewer_set_orientation(RSTTO_THUMBNAIL_VIEWER(thumbnail_viewer), GTK_ORIENTATION_HORIZONTAL);
-    }
-    else
-    {
-        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item_vtv), TRUE);
-        gtk_box_pack_start(GTK_BOX(main_hbox), thumbnail_viewer, FALSE, TRUE, 0);
-        rstto_thumbnail_viewer_set_orientation(RSTTO_THUMBNAIL_VIEWER(thumbnail_viewer), GTK_ORIENTATION_VERTICAL);
-    }
-
-
-    gtk_box_pack_start(GTK_BOX(main_vbox), menu_bar, FALSE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(main_vbox), app_tool_bar, FALSE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(main_vbox), main_hbox, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(main_vbox), status_bar, FALSE, TRUE, 0);
-
-    //rstto_picture_viewer_fit_scale(RSTTO_PICTURE_VIEWER(viewer));
-
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_fit, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_100, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_out, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), zoom_in, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), spacer, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), forward, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), previous, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), separator, 0);
-    gtk_toolbar_insert(GTK_TOOLBAR(app_tool_bar), open, 0);
-
-    g_signal_connect(G_OBJECT(zoom_fit), "clicked", G_CALLBACK(cb_rstto_zoom_fit), viewer);
-    g_signal_connect(G_OBJECT(zoom_100), "clicked", G_CALLBACK(cb_rstto_zoom_100), viewer);
-    g_signal_connect(G_OBJECT(zoom_in), "clicked", G_CALLBACK(cb_rstto_zoom_in), viewer);
-    g_signal_connect(G_OBJECT(zoom_out), "clicked", G_CALLBACK(cb_rstto_zoom_out), viewer);
-    g_signal_connect(G_OBJECT(forward), "clicked", G_CALLBACK(cb_rstto_forward), navigator);
-    g_signal_connect(G_OBJECT(previous), "clicked", G_CALLBACK(cb_rstto_previous), navigator);
-    if(toolbar_open_dir == TRUE)
-        g_signal_connect(G_OBJECT(open), "clicked", G_CALLBACK(cb_rstto_open_dir), navigator);
-    else
-        g_signal_connect(G_OBJECT(open), "clicked", G_CALLBACK(cb_rstto_open), navigator);
-
-    g_signal_connect(G_OBJECT(menu_item_clear_recent), "activate", G_CALLBACK(cb_rstto_clear_recent), recent_manager);
-
-    g_signal_connect(G_OBJECT(menu_item_quit), "activate", G_CALLBACK(gtk_main_quit), NULL);
-    g_signal_connect(G_OBJECT(menu_item_open), "activate", G_CALLBACK(cb_rstto_open), navigator);
-    g_signal_connect(G_OBJECT(menu_item_open_dir), "activate", G_CALLBACK(cb_rstto_open_dir), navigator);
-    g_signal_connect(G_OBJECT(menu_item_help_about), "activate", G_CALLBACK(cb_rstto_help_about), window);
-
-    g_signal_connect(G_OBJECT(recent_chooser_menu), "item-activated", G_CALLBACK(cb_rstto_open_recent), navigator);
-
-    g_signal_connect(G_OBJECT(menu_item_forward), "activate", G_CALLBACK(cb_rstto_forward), navigator);
-    g_signal_connect(G_OBJECT(menu_item_back), "activate", G_CALLBACK(cb_rstto_previous), navigator);
-    g_signal_connect(G_OBJECT(menu_item_first), "activate", G_CALLBACK(cb_rstto_first), navigator);
-    g_signal_connect(G_OBJECT(menu_item_last), "activate", G_CALLBACK(cb_rstto_last), navigator);
-
-    g_signal_connect(G_OBJECT(menu_item_rotate_left), "activate", G_CALLBACK(cb_rstto_rotate_ccw), navigator);
-    g_signal_connect(G_OBJECT(menu_item_rotate_right), "activate", G_CALLBACK(cb_rstto_rotate_cw), navigator);
-    g_signal_connect(G_OBJECT(menu_item_flip_v), "activate", G_CALLBACK(cb_rstto_flip_v), navigator);
-    g_signal_connect(G_OBJECT(menu_item_flip_h), "activate", G_CALLBACK(cb_rstto_flip_h), navigator);
-
-    g_signal_connect(G_OBJECT(menu_item_toggle_toolbar), "activate", G_CALLBACK(cb_rstto_toggle_toolbar), thumbnail_viewer);
-
-    g_signal_connect(G_OBJECT(menu_item_vtv), "activate", G_CALLBACK(cb_rstto_show_tv_v), thumbnail_viewer);
-    g_signal_connect(G_OBJECT(menu_item_htv), "activate", G_CALLBACK(cb_rstto_show_tv_h), thumbnail_viewer);
-    g_signal_connect(G_OBJECT(menu_item_ntv), "activate", G_CALLBACK(cb_rstto_hide_tv), thumbnail_viewer);
-
-    g_signal_connect(G_OBJECT(menu_item_play), "activate", G_CALLBACK(cb_rstto_toggle_play), navigator);
-    g_signal_connect(G_OBJECT(menu_item_pause), "activate", G_CALLBACK(cb_rstto_toggle_play), navigator);
-    g_signal_connect(G_OBJECT(menu_item_view_fs), "activate", G_CALLBACK(cb_rstto_toggle_fullscreen), window);
-
-    g_signal_connect(G_OBJECT(window), "window-state-event", G_CALLBACK(cb_rstto_fullscreen), viewer);
-    g_signal_connect(G_OBJECT(window), "configure-event", G_CALLBACK(cb_rstto_main_window_configure_event), NULL);
-
-    gtk_container_add(GTK_CONTAINER(window), main_vbox);
-
     gtk_widget_show_all(window);
     gtk_widget_hide(menu_item_pause);
     gtk_widget_show(viewer);
@@ -435,7 +465,6 @@ int main(int argc, char **argv)
         gtk_widget_hide(GTK_WIDGET(app_tool_bar));   
     }
 
-
     gtk_main();
     xfce_rc_flush(xfce_rc);
     xfce_rc_close(xfce_rc);
@@ -529,9 +558,38 @@ cb_rstto_previous(GtkToolItem *item, RsttoNavigator *navigator)
 static void
 cb_rstto_nav_file_changed(RsttoNavigator *navigator, gint nr, RsttoNavigatorEntry *entry, GtkWindow *window)
 {
-    ThunarVfsInfo *info = rstto_navigator_entry_get_info(entry);
-    const gchar *filename = info->display_name;
+    ThunarVfsInfo *info = NULL;
+    const gchar *filename = NULL;
     gchar *title;
+
+    if(entry)
+    {
+        info = rstto_navigator_entry_get_info(entry);
+        filename = info->display_name;
+        gtk_widget_set_sensitive(menu_item_close, TRUE);
+        gtk_widget_set_sensitive(menu_item_first, TRUE);
+        gtk_widget_set_sensitive(menu_item_last, TRUE);
+        gtk_widget_set_sensitive(menu_item_back, TRUE);
+        gtk_widget_set_sensitive(menu_item_forward, TRUE);
+
+        gtk_widget_set_sensitive(GTK_WIDGET(tool_item_forward), TRUE);
+        gtk_widget_set_sensitive(GTK_WIDGET(tool_item_previous), TRUE);
+    }
+    else
+    {
+        gtk_widget_set_sensitive(menu_item_close, FALSE);
+        if (rstto_navigator_get_n_files(navigator) == 0)
+        {
+            gtk_widget_set_sensitive(menu_item_first, FALSE);
+            gtk_widget_set_sensitive(menu_item_last, FALSE);
+            gtk_widget_set_sensitive(menu_item_back, FALSE);
+            gtk_widget_set_sensitive(menu_item_forward, FALSE);
+
+            gtk_widget_set_sensitive(GTK_WIDGET(tool_item_forward), FALSE);
+            gtk_widget_set_sensitive(GTK_WIDGET(tool_item_previous), FALSE);
+        }
+    }
+
     if(filename)
     {
         title = g_strconcat(PACKAGE_NAME, " - ", filename, NULL);
@@ -540,6 +598,47 @@ cb_rstto_nav_file_changed(RsttoNavigator *navigator, gint nr, RsttoNavigatorEntr
     }
     else
         gtk_window_set_title(window, PACKAGE_STRING);
+
+    if (menu_apps)
+    {
+        gtk_container_foreach(GTK_CONTAINER(menu_apps), (GtkCallback)gtk_widget_destroy, NULL);
+        if(menu_apps_list)
+        {
+            g_list_foreach(menu_apps_list, (GFunc)g_object_unref, NULL);
+            g_list_free(menu_apps_list);
+            menu_apps_list = NULL;
+        }
+        if(info)
+        {
+            menu_apps_list = thunar_vfs_mime_database_get_applications(mime_dbase, info->mime_info);
+            GList *iter = menu_apps_list;
+            if (iter == NULL)
+            {
+                GtkWidget *bottom_menu_item = gtk_menu_item_new_with_mnemonic(_("No applications available"));
+                gtk_menu_shell_append(GTK_MENU_SHELL(menu_apps), bottom_menu_item);
+                gtk_widget_set_sensitive(bottom_menu_item, FALSE);
+                gtk_widget_show(bottom_menu_item);
+            }
+            while(iter)
+            {
+                GtkWidget *menu_item = gtk_image_menu_item_new_with_label(thunar_vfs_mime_application_get_name(iter->data));
+                GtkWidget *image = gtk_image_new_from_icon_name(thunar_vfs_mime_handler_lookup_icon_name(iter->data, icon_theme), GTK_ICON_SIZE_MENU);
+                gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item), image);
+                gtk_menu_shell_append(GTK_MENU_SHELL(menu_apps), menu_item);
+                g_object_set_data(iter->data, "entry", entry);
+                g_signal_connect(menu_item, "activate", G_CALLBACK(cb_rstto_spawn_app), iter->data);
+                gtk_widget_show(menu_item);
+                iter = g_list_next(iter);
+            }
+        }
+        else
+        {
+            GtkWidget *bottom_menu_item = gtk_menu_item_new_with_mnemonic(_("No applications available"));
+            gtk_menu_shell_append(GTK_MENU_SHELL(menu_apps), bottom_menu_item);
+            gtk_widget_set_sensitive(bottom_menu_item, FALSE);
+            gtk_widget_show(bottom_menu_item);
+        }
+    }
 }
 
 static void
@@ -785,7 +884,6 @@ cb_rstto_open(GtkToolItem *item, RsttoNavigator *navigator)
             {
                 RsttoNavigatorEntry *entry = rstto_navigator_entry_new(info);
                 rstto_navigator_add (navigator, entry);
-
                 gchar *uri = thunar_vfs_path_dup_uri(info->path);
                 gtk_recent_manager_add_item(recent_manager, uri);
                 g_free(uri);
@@ -984,7 +1082,17 @@ cb_rstto_main_window_configure_event (GtkWidget *widget, GdkEventConfigure *even
 static void
 cb_rstto_clear_recent(GtkWidget *widget, GtkRecentManager *manager)
 {
-    g_timeout_add(150, (GSourceFunc)rstto_clear_recent, manager);
+    GtkWidget *dialog = gtk_message_dialog_new(NULL,
+                                    GTK_DIALOG_MODAL,
+                                    GTK_MESSAGE_ERROR,
+                                    GTK_BUTTONS_OK_CANCEL,
+                                    _("Are you sure you want to clear ristretto's list of recently opened documents?"));
+    gint result = gtk_dialog_run(GTK_DIALOG(dialog));
+    if (result == GTK_RESPONSE_OK)
+    {
+        g_timeout_add(150, (GSourceFunc)rstto_clear_recent, manager);
+    }
+    gtk_widget_destroy(dialog);
 }
 
 static gboolean
@@ -1002,3 +1110,30 @@ rstto_clear_recent(GtkRecentManager *manager)
     }
     return FALSE;
 }
+
+static void
+cb_rstto_spawn_app(GtkWidget *widget, ThunarVfsMimeApplication *app)
+{
+    ThunarVfsInfo *info = rstto_navigator_entry_get_info(g_object_get_data(G_OBJECT(app), "entry"));
+    GList *list = g_list_prepend(NULL, info->path);
+    thunar_vfs_mime_handler_exec(THUNAR_VFS_MIME_HANDLER(app), NULL, list, NULL);
+}
+
+static void
+cb_rstto_close_current(GtkWidget *item, RsttoNavigator *navigator)
+{
+    RsttoNavigatorEntry *entry = rstto_navigator_get_file(navigator);
+    if (entry)
+    {
+        rstto_navigator_remove(navigator, entry);    
+        rstto_navigator_entry_free(entry);
+        if (rstto_navigator_get_n_files(navigator) == 0)
+        {
+            gtk_widget_set_sensitive(item, FALSE);
+        }
+    }
+    else
+    {
+        gtk_widget_set_sensitive(item, FALSE);
+    }
+}
