@@ -224,6 +224,16 @@ rstto_navigator_jump_forward (RsttoNavigator *navigator)
                       navigator->file_iter->data,
                       NULL);
     }
+    else
+    {
+        g_signal_emit(G_OBJECT(navigator),
+                      rstto_navigator_signals[RSTTO_NAVIGATOR_SIGNAL_ITER_CHANGED],
+                      0,
+                      -1,
+                      NULL,
+                      NULL);
+
+    }
 }
 
 void
@@ -338,6 +348,57 @@ rstto_navigator_add (RsttoNavigator *navigator, RsttoNavigatorEntry *entry)
     g_signal_emit(G_OBJECT(navigator), rstto_navigator_signals[RSTTO_NAVIGATOR_SIGNAL_NEW_ENTRY], 0, g_list_index(navigator->file_list, entry), entry, NULL);
 }
 
+void
+rstto_navigator_remove (RsttoNavigator *navigator, RsttoNavigatorEntry *entry)
+{
+    if(navigator->file_iter)
+    {
+        if(navigator->file_iter->data == entry)
+        {
+            navigator->old_position = rstto_navigator_get_position(navigator);
+            rstto_navigator_entry_free_pixbuf(navigator->file_iter->data);
+            navigator->file_iter = g_list_next(navigator->file_iter);
+            if(!navigator->file_iter)
+                navigator->file_iter = g_list_first(navigator->file_list);
+
+            navigator->file_list = g_list_remove(navigator->file_list, entry);
+            if(g_list_length(navigator->file_list) == 0)
+            {
+                navigator->file_iter = NULL;
+                navigator->file_list = NULL;
+            }
+            g_signal_emit(G_OBJECT(navigator), rstto_navigator_signals[RSTTO_NAVIGATOR_SIGNAL_REORDERED], 0, NULL);
+            if(navigator->file_iter)
+            {
+                g_signal_emit(G_OBJECT(navigator),
+                              rstto_navigator_signals[RSTTO_NAVIGATOR_SIGNAL_ITER_CHANGED],
+                              0,
+                              g_list_position(navigator->file_list, navigator->file_iter),
+                              navigator->file_iter->data,
+                              NULL);
+            }
+            else
+            {
+                g_signal_emit(G_OBJECT(navigator),
+                              rstto_navigator_signals[RSTTO_NAVIGATOR_SIGNAL_ITER_CHANGED],
+                              0,
+                              -1,
+                              NULL,
+                              NULL);
+
+            }
+            return;
+        }
+    }
+    navigator->file_list = g_list_remove(navigator->file_list, entry);
+    if(g_list_length(navigator->file_list) == 0)
+    {
+        navigator->file_iter = NULL;
+        navigator->file_list = NULL;
+    }
+    g_signal_emit(G_OBJECT(navigator), rstto_navigator_signals[RSTTO_NAVIGATOR_SIGNAL_REORDERED], 0, NULL);
+}
+
 void
 rstto_navigator_clear (RsttoNavigator *navigator)
 {
