@@ -1,4 +1,6 @@
 /*
+        g_object_unref(viewer->priv->src_pixbuf);
+        viewer->priv->src_pixbuf = NULL;
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -365,54 +367,57 @@ rstto_picture_viewer_set_scroll_adjustments(RsttoPictureViewer *viewer, GtkAdjus
 static void
 cb_rstto_picture_viewer_value_changed(GtkAdjustment *adjustment, RsttoPictureViewer *viewer)
 {
+    gdouble scale = 1.0;
+    gdouble width = 1.0;
+    gdouble height = 1.0;
+    GtkWidget *widget = GTK_WIDGET(viewer);
     RsttoNavigatorEntry *entry = rstto_navigator_get_file(viewer->priv->navigator);
-    gdouble scale = rstto_navigator_entry_get_scale(entry);
-    if (viewer->priv->src_pixbuf)
+    if (entry)
     {
-        gdouble width = (gdouble)gdk_pixbuf_get_width(viewer->priv->src_pixbuf);
-        gdouble height = (gdouble)gdk_pixbuf_get_height(viewer->priv->src_pixbuf);
-
-        GdkPixbuf *tmp_pixbuf = NULL;
-        if (viewer->hadjustment && viewer->vadjustment)
+        scale = rstto_navigator_entry_get_scale(entry);
+        width = (gdouble)gdk_pixbuf_get_width(viewer->priv->src_pixbuf);
+        height = (gdouble)gdk_pixbuf_get_height(viewer->priv->src_pixbuf);
+    }
+    GdkPixbuf *tmp_pixbuf = NULL;
+    if (viewer->vadjustment && viewer->hadjustment)
+    {
+        if (scale < 1.0)
         {
-            if (scale < 1.0)
-            {
-                tmp_pixbuf = gdk_pixbuf_new_subpixbuf(viewer->priv->src_pixbuf,
-                            viewer->hadjustment->value / scale >= 0?
-                                viewer->hadjustment->value / scale : 0,
-                            viewer->vadjustment->value / scale >= 0?
-                                viewer->vadjustment->value / scale : 0,
-                            ((GTK_WIDGET(viewer)->allocation.width/scale)) < width?
-                                GTK_WIDGET(viewer)->allocation.width/scale:width,
-                            ((GTK_WIDGET(viewer)->allocation.height/scale)) < height?
-                                GTK_WIDGET(viewer)->allocation.height/scale:height);
-            }
-            else
-            {
-                tmp_pixbuf = viewer->priv->src_pixbuf;
-                g_object_ref(tmp_pixbuf);
-            }
+            tmp_pixbuf = gdk_pixbuf_new_subpixbuf(viewer->priv->src_pixbuf,
+                                              viewer->hadjustment->value / scale >= 0?
+                                                viewer->hadjustment->value / scale : 0,
+                                              viewer->vadjustment->value / scale >= 0?
+                                                viewer->vadjustment->value / scale : 0,
+                                              ((widget->allocation.width/scale)) < width?
+                                                widget->allocation.width/scale:width,
+                                              ((widget->allocation.height/scale))< height?
+                                                widget->allocation.height/scale:height);
         }
-
-        if(viewer->priv->dst_pixbuf)
+        else
         {
-            g_object_unref(viewer->priv->dst_pixbuf);
-            viewer->priv->dst_pixbuf = NULL;
-        }
-
-        if(tmp_pixbuf)
-        {
-            gint dst_width = gdk_pixbuf_get_width(tmp_pixbuf)*scale;
-            gint dst_height = gdk_pixbuf_get_height(tmp_pixbuf)*scale;
-            viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple(tmp_pixbuf,
-                                    dst_width>0?dst_width:1,
-                                    dst_height>0?dst_height:1,
-                                    GDK_INTERP_BILINEAR);
-            g_object_unref(tmp_pixbuf);
-            tmp_pixbuf = NULL;
+            tmp_pixbuf = viewer->priv->src_pixbuf;
+            g_object_ref(tmp_pixbuf);
         }
     }
-    rstto_picture_viewer_paint((GtkWidget *)viewer);
+
+    if(viewer->priv->dst_pixbuf)
+    {
+        g_object_unref(viewer->priv->dst_pixbuf);
+        viewer->priv->dst_pixbuf = NULL;
+    }
+
+    if(tmp_pixbuf)
+    {
+        gint dst_width = gdk_pixbuf_get_width(tmp_pixbuf)*scale;
+        gint dst_height = gdk_pixbuf_get_height(tmp_pixbuf)*scale;
+        viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple(tmp_pixbuf,
+                                dst_width>0?dst_width:1,
+                                dst_height>0?dst_height:1,
+                                GDK_INTERP_BILINEAR);
+        g_object_unref(tmp_pixbuf);
+        tmp_pixbuf = NULL;
+    }
+    rstto_picture_viewer_paint(widget);
 }
 
 GtkWidget *
@@ -621,6 +626,14 @@ rstto_picture_viewer_refresh(RsttoPictureViewer *viewer)
             gdk_cursor_unref(cursor);
         }
     }
+    else
+    {
+        if(viewer->priv->dst_pixbuf)
+        {
+            g_object_unref(viewer->priv->dst_pixbuf);
+            viewer->priv->dst_pixbuf = NULL;
+        }
+    }
     return changed;
 }
 
@@ -630,7 +643,7 @@ cb_rstto_picture_viewer_update_image(RsttoPictureViewer *viewer)
     gulong millisec = 0;
 
     g_timer_elapsed(viewer->priv->timer, &millisec);
-    if (millisec > 150)
+    if (millisec >= 300)
     {
         g_timer_stop(viewer->priv->timer);
         viewer->priv->timeout_id = 0;
@@ -644,16 +657,29 @@ static void
 cb_rstto_picture_viewer_nav_file_changed(RsttoNavigator *nav, gint nr, RsttoNavigatorEntry *entry, RsttoPictureViewer *viewer)
 {
     GtkWidget *widget = GTK_WIDGET(viewer);
-    if (GTK_WIDGET_REALIZED(widget))
+    if(entry)
     {
-        GdkCursor *cursor = gdk_cursor_new(GDK_WATCH);
-        gdk_window_set_cursor(widget->window, cursor);
-        gdk_cursor_unref(cursor);
+        if (GTK_WIDGET_REALIZED(widget))
+        {
+            GdkCursor *cursor = gdk_cursor_new(GDK_WATCH);
+            gdk_window_set_cursor(widget->window, cursor);
+            gdk_cursor_unref(cursor);
+        }
+        g_timer_start(viewer->priv->timer);
+        if (viewer->priv->timeout_id == 0)
+            viewer->priv->timeout_id = g_timeout_add(300, (GSourceFunc)cb_rstto_picture_viewer_update_image, viewer);
+    }
+    else
+    {
+        g_object_unref(viewer->priv->src_pixbuf);
+        viewer->priv->src_pixbuf = NULL;
+        g_object_unref(viewer->priv->dst_pixbuf);
+        viewer->priv->dst_pixbuf = NULL;
+        if (GTK_WIDGET_REALIZED(widget))
+        {
+            rstto_picture_viewer_paint(GTK_WIDGET(viewer));
+        }
     }
-    g_timer_start(viewer->priv->timer);
-    if (viewer->priv->timeout_id == 0)
-        viewer->priv->timeout_id = g_timeout_add(150, (GSourceFunc)cb_rstto_picture_viewer_update_image, viewer);
-
 }
 
 static void
@@ -668,23 +694,23 @@ rstto_picture_viewer_update(RsttoPictureViewer *viewer)
         gdk_cursor_unref(cursor);
     }
 
-    if(viewer->priv->src_pixbuf)
-        g_object_unref(viewer->priv->src_pixbuf);
-
-    viewer->priv->src_pixbuf = rstto_navigator_entry_get_pixbuf(entry);
-
     if(viewer->priv->src_pixbuf)
     {
+        g_object_unref(viewer->priv->src_pixbuf);
+        viewer->priv->src_pixbuf = NULL;
+    }
+
+    if(entry)
+    {
+        viewer->priv->src_pixbuf = rstto_navigator_entry_get_pixbuf(entry);
         g_object_ref(viewer->priv->src_pixbuf);
-        if (GTK_WIDGET_REALIZED(widget))
-        {
-            rstto_picture_viewer_refresh(viewer);
-            rstto_picture_viewer_paint(GTK_WIDGET(viewer));
-        }
     }
 
     if(GTK_WIDGET_REALIZED(widget))
     {
+        rstto_picture_viewer_refresh(viewer);
+        rstto_picture_viewer_paint(GTK_WIDGET(viewer));
+
         GdkCursor *cursor = gdk_cursor_new(GDK_LEFT_PTR);
         gdk_window_set_cursor(widget->window, cursor);
         gdk_cursor_unref(cursor);
